@@ -9,14 +9,15 @@ from scipy.stats import chi2, norm
 from functools import partial
 from copy import deepcopy
 from typing import List, Tuple
-from scipy.optimize import minimize_scalar, minimize
+from scipy.optimize import minimize_scalar
 import pandas as pd
 import numpy as np
 import jax
 import dill
 import re
 import os
-globalk = False
+
+
 class Model():
     def __init__(self, dist: str, left=4, mask_size=0, model_name='window', param_mode='window'):
         self.dist = dist
@@ -108,8 +109,6 @@ class Model():
                 k = ps['mu_k'] + ps['b_k'] * np.log(fixed)
             else:
                 k = np.zeros(len(r))
-        if globalk:
-            print(data, r, k, w)
         data, r, k, w = self.update_mask(data, r, k, w)
         mask = self.mask
         f = partial(self.negloglik, r=r, k=k, data=data, w=w, mask=mask)
@@ -296,11 +295,6 @@ def wald_test(counts: Tuple[tuple, np.ndarray, np.ndarray, np.ndarray],
             b_var = np.clip(b_var, 0.0, np.inf)
             b_p = b_r.x
             correct = (a_var >= 0) & (b_var >= 0) & (a_var + b_var > 0) & np.isfinite(a_var) & np.isfinite(b_var)
-            if globalk:
-                print(a_r)
-                print(a_var ** 0.5)
-                print(b_r)
-                print(b_var ** 0.5)
             globalk = False
             if logit_transform:
                 a_p, a_var = transform_p(a_p, a_var)
